@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-05-06'; # DATE
-our $VERSION = '1.13'; # VERSION
+our $DATE = '2015-06-11'; # DATE
+our $VERSION = '1.14'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1266,7 +1266,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.13 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-05-06.
+This document describes version 1.14 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-06-11.
 
 =head1 DESCRIPTION
 
@@ -1782,23 +1782,23 @@ settings of the Perinci::CmdLine, etc.
 
 Default is from PERINCI_CMDLINE_PROGRAM_NAME environment or from $0.
 
-=head2 riap_client => float (default: 1.1)
-
-Specify L<Riap> protocol version to use. Will be passed to C<riap_client_args>.
-
 =head2 riap_client => obj
 
-Set to L<Perinci::Access> (or compatible) instance. PC::Lite uses lighter
-version L<Perinci::Access::Lite>.
+Set to Riap client instance, should you want to create one yourself. Otherwise
+will be set L<Perinci::Access> (in PC:Classic), or L<Perinci::Access::Lite> (in
+PC:Lite).
 
 =head2 riap_version => float (default: 1.1)
 
-Will be passed to Riap client constructor as well.
+Specify L<Riap> protocol version to use. Will be passed to Riap client
+constructor (unless you already provide a Riap client object, see
+C<riap_client>).
 
 =head2 riap_client_args => hash
 
-Arguments to pass to L<Perinci::Access> constructor. This is useful for passing
-e.g. HTTP basic authentication to Riap client
+Arguments to pass to Riap client constructor. Will be used unless you create
+your own Riap client object (see C<riap_client>). One of the things this
+attribute is used is to pass HTTP basic authentication to Riap client
 (L<Perinci::Access::HTTP::Client>):
 
  riap_client_args => {handler_args => {user=>$USER, password=>$PASS}}
